@@ -22,24 +22,27 @@ optional arguments:
 """
 
 import argparse
-from hathi.mysql import MysqlScanner
-from hathi.scanner import Scanner
-from hathi.mssql import MssqlScanner
-from hathi.postgres import PostgresScanner
-import time
 import asyncio
-
-from typing import Dict, List, Optional, Set, Type, Union
+import ipaddress
+import json
+import logging
+import time
 from enum import Enum
-
+from typing import Dict, Generator, List, Optional, Set, Tuple, Type, Union
 
 from rich.console import Console
 from rich.table import Table
-import json
+from rich.progress import Progress, BarColumn
 
+from hathi.mssql import MssqlScanner
+from hathi.mysql import MysqlScanner
+from hathi.postgres import PostgresScanner
+from hathi.scanner import Scanner
 
 DEFAULT_TIMEOUT = 1.0  # For initial TCP scan
 
+logger = logging.getLogger(__name__)
+
 
 class HostType(Enum):
     Postgres = "postgres"
@@ -62,7 +65,9 @@ SCANNER_CLS: Dict[HostType, Type[Scanner]] = {
 }
 
 
-async def try_hosts(hosts: List[str], types_to_scan: Set[HostType]):
+async def try_hosts(
+    hosts: List[str], types_to_scan: Set[HostType]
+) -> Generator[Tuple[str, HostType, bool], None, None]:
     found = 0
     for host in hosts:
         for host_type in types_to_scan:
@@ -70,11 +75,11 @@ async def try_hosts(hosts: List[str], types_to_scan: Set[HostType]):
             try:
                 future = asyncio.open_connection(host=host, port=port)
                 _, w = await asyncio.wait_for(future, timeout=DEFAULT_TIMEOUT)
-                yield host, host_type
+                yield host, host_type, True
                 found += 1
                 w.close()
             except (asyncio.TimeoutError, OSError):
-                pass
+                yield host, host_type, False
 
 
 async def scan(
@@ -85,19 +90,37 @@ async def scan(
     verbose=False,
     multiple: bool = False,
     types_to_scan: Set[HostType] = {HostType.Postgres, HostType.Mssql},
+    database: str = None,
 ):
-    open_hosts = []
-    async for open_host in try_hosts(hosts, types_to_scan):
-        open_hosts.append(open_host)
+    open_hosts: List[Tuple[str, HostType]] = []
+    with Progress(
+        "[progress.description]{task.description}",
+        BarColumn(),
+        "[progress.percentage]{task.percentage:>3.0f}%",
+    ) as progress:
+        t = progress.add_task(
+            "Scanning hosts for open ports",
+            total=len(hosts) * len(types_to_scan),
+            visible=verbose,
+        )
+        async for host, host_type, is_open in try_hosts(hosts, types_to_scan):
+            progress.update(t, advance=1, description=f"Scanning {host}")
+            if is_open:
+                open_hosts.append((host, host_type))
 
     matched_connections = []
 
     for host, host_type in open_hosts:
-        database = DEFAULT_DATABASE_NAME[host_type]
+        if not database:
+            _database = DEFAULT_DATABASE_NAME[host_type]
+        else:
+            _database = database
         if verbose:
-            console.print(f"[green]Scanning {host} as {host_type}")
+            console.print(
+                f"[green]Scanning {host} as {host_type} with database {_database}"
+            )
         scanner = SCANNER_CLS[host_type](
-            host, database, usernames, passwords, hostname, verbose, multiple
+            host, _database, usernames, passwords, hostname, verbose, multiple
         )
         async for match in scanner.scan():
             matched_connections.append(match)
@@ -110,9 +133,12 @@ def main():
         description="Port scan and dictionary attack PostgreSQL, MSSQL and MySQL servers."
     )
     parser.add_argument(
-        "hosts", metavar="host", type=str, nargs="+", help="host to scan"
+        "hosts", metavar="host", type=str, nargs="*", help="host to scan"
     )
     parser.add_argument("--username", type=str, nargs="+", help="specific username")
+    parser.add_argument(
+        "--range", type=str, nargs="+", help="CIDR range, e.g. 192.168.1.0/24"
+    )
     parser.add_argument(
         "--usernames",
         type=str,
@@ -144,8 +170,20 @@ def main():
         action="store_true",
         help="Seek multiple username/password pairs on a single host",
     )
+    parser.add_argument("--database", type=str, help="try a specific database name")
 
     args = parser.parse_args()
+    hosts = args.hosts
+    if args.range:
+        for r in args.range:
+            hosts.extend(str(ip) for ip in ipaddress.IPv4Network(r))
+
+    if not hosts:
+        logger.error(
+            "No hosts scanned, you need to specify the hostnames, or use --range."
+        )
+        exit()
+
     start = time.time()
 
     if args.mssql:
@@ -167,13 +205,14 @@ def main():
 
     results = asyncio.run(
         scan(
-            args.hosts,
+            hosts,
             usernames,
             args.passwords,
             args.hostname,
             verbose=not args.json,
             multiple=args.multiple,
             types_to_scan=types_to_scan,
+            database=args.database,
         )
     )
 
